@@ -22,6 +22,7 @@ import gdown
 import numpy as np
 from sklearn.datasets import fetch_20newsgroups, load_breast_cancer
 from sklearn.model_selection import train_test_split
+from sklearn.preprocessing import StandardScaler
 import torch
 import torchvision
 
@@ -43,6 +44,7 @@ def load_dataset(
     vectorizer: str = "tfidf",
     return_vectorizer: bool = False,
     image_size: int = 64,
+    preprocessed_covidx: bool = False,
 ) -> Tuple[object, object]:
     """
     Returns a tuple of torchvision dataset objects.
@@ -79,6 +81,10 @@ def load_dataset(
         This is only used for datasets [name = ag_news | 20newsgroups].
     image_size: int
         The image size to use for COVID19 datasets.
+    preprocessed_covidx: bool
+        Whether to use the preprocessed COVID19 datasets or not.
+        This requires the use of `modules/export_covid19_dataset`
+        in the package repository.
 
     Returns
     -------
@@ -206,11 +212,11 @@ def load_dataset(
         train_dataset, test_dataset = load_wdbc()
     elif name == "binary_covid":
         train_dataset, test_dataset = load_binary_covid19(
-            transform=transform, size=image_size
+            transform=transform, size=image_size, preprocessed=preprocessed_covidx
         )
     elif name == "multi_covid":
         train_dataset, test_dataset = load_multi_covid19(
-            transform=transform, size=image_size
+            transform=transform, size=image_size, preprocessed=preprocessed_covidx
         )
     return (
         (train_dataset, test_dataset, vectorizer)
@@ -382,21 +388,22 @@ def load_wdbc(test_size: float = 3e-1, seed: int = 42):
     train_features, test_features, train_labels, test_labels = train_test_split(
         features, labels, test_size=test_size, random_state=seed, shuffle=True
     )
+    scaler = StandardScaler()
+    train_features = scaler.fit_transform(train_features)
+    test_features = scaler.fit_transform(test_features)
     train_features = train_features.astype("float32")
-    train_labels = train_labels.astype("uint8")
     test_features = test_features.astype("float32")
-    test_labels = test_labels.astype("uint8")
     train_dataset = torch.utils.data.TensorDataset(
         torch.from_numpy(train_features), torch.from_numpy(train_labels)
     )
     test_dataset = torch.utils.data.TensorDataset(
-        torch.from_numpy(test_labels), torch.from_numpy(test_labels)
+        torch.from_numpy(test_features), torch.from_numpy(test_labels)
     )
     return train_dataset, test_dataset
 
 
 def load_binary_covid19(
-    transform: torchvision.transforms, size: int = 64
+    transform: torchvision.transforms, size: int = 64, preprocessed: bool = False
 ) -> Tuple[torch.utils.data.Dataset, torch.utils.data.Dataset]:
     """
     Returns a tuple of the tensor datasets for the
@@ -408,6 +415,8 @@ def load_binary_covid19(
         The transformation pipeline to use for image preprocessing.
     size: int
         The size to use for image resizing.
+    preprocessed: bool
+        Whether to load preprocessed dataset or not.
 
     Returns
     -------
@@ -422,15 +431,15 @@ def load_binary_covid19(
     if not os.path.exists(os.path.join(dataset_path, "BinaryCOVID19Dataset")):
         download_binary_covid19_dataset()
         unzip_dataset(os.path.join(dataset_path, "BinaryCOVID19Dataset.tar.xz"))
-    train_data, test_data = (
-        BinaryCOVID19Dataset(train=True, transform=transform),
-        BinaryCOVID19Dataset(train=False, transform=transform),
+    (train_data, test_data) = (
+        BinaryCOVID19Dataset(train=True, preprocessed=preprocessed, size=size),
+        BinaryCOVID19Dataset(train=False, preprocessed=preprocessed, size=size),
     )
     return train_data, test_data
 
 
 def load_multi_covid19(
-    transform: torchvision.transforms, size: int = 64
+    transform: torchvision.transforms, size: int = 64, preprocessed: bool = False
 ) -> Tuple[torch.utils.data.Dataset, torch.utils.data.Dataset]:
     """
     Returns a tuple of the tensor datasets for the
@@ -442,6 +451,8 @@ def load_multi_covid19(
         The transformation pipeline to use for image preprocessing.
     size: int
         The size to use for image resizing.
+    preprocessed: bool
+        Whether to load preprocessed dataset or not.
 
     Returns
     -------
@@ -456,8 +467,8 @@ def load_multi_covid19(
     if not os.path.exists(os.path.join(dataset_path, "MultiCOVID19Dataset")):
         download_covidx5_dataset()
         unzip_dataset(os.path.join(dataset_path, "MultiCOVID19Dataset.tar.xz"))
-    train_data, test_data = (
-        MultiCOVID19Dataset(train=True, transform=transform),
-        MultiCOVID19Dataset(train=False, transform=transform),
+    (train_data, test_data) = (
+        MultiCOVID19Dataset(train=True, preprocessed=preprocessed, size=size),
+        MultiCOVID19Dataset(train=False, preprocessed=preprocessed, size=size),
     )
     return train_data, test_data
